// GoToSocial
// Copyright (C) GoToSocial Authors admin@gotosocial.org
// SPDX-License-Identifier: AGPL-3.0-or-later
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package config

// Instance federation mode determines how this
// instance federates with others (if at all).
const (
	InstanceFederationModeBlocklist = "blocklist"
	InstanceFederationModeAllowlist = "allowlist"
	InstanceFederationModeDefault   = InstanceFederationModeBlocklist
)

// Request header filter mode determines how
// this instance will perform request filtering.
const (
	RequestHeaderFilterModeAllow    = "allow"
	RequestHeaderFilterModeBlock    = "block"
	RequestHeaderFilterModeDisabled = ""
)

// Instance stats mode determines if and how
// stats about the instance are served at
// nodeinfo and api/v1|v2/instance endpoints.
const (
	InstanceStatsModeDefault = ""
	InstanceStatsModeServe   = "serve"
	InstanceStatsModeZero    = "zero"
	InstanceStatsModeBaffle  = "baffle"
)
